=======
Credits
=======

Development Lead
----------------

* Eric J. Ma <ericmajinglong (at) gmail.com>

Contributors
------------

- Nora Kassner <nora.kassner (at) t-online.de>
- Christian Diener <mail (at) cdiener.com>
- Thijs Hermans <hermansthijs91 (at) gmail.com>
- R. M. Keelan Downton <keelan.downton (at) gmail.com>
- Maximilian T. Strauss <straussmaximilian (at) gmail.com>
- Brian Cajes @bcajes
- Ashutosh Chandra @ashu16993
- Rabeez Riaz <19100165 (at) lums.edu.pk>
- Erick Armingol <earmingol (at) eng.ucsd.edu>
- Walter Hernandez <walter (dot) hernandez (dot) 18 (at) ucl.ac.uk>
- Eduarda Centeno <eduardacenteno (at) hotmail.com)
